import axios from 'axios'
import qs from 'qs'
import storageUtil from '../util/storageUtil'
import {Message} from 'element-ui'
import router from '../router'
import {BASE_URL} from './baseUrl'

// //  这个baseUrl要根据实际情况进行改变
axios.defaults.timeout = 60000;
axios.defaults.headers.common['Content-Type'] =
    'application/json; charset=UTF-8';
axios.defaults.headers.common['Access-Control-Allow-Origin'] = '*';

//
// // 请求拦截器 添加token
// axios.interceptors.request.use(
//     config => {
//         return config
//     },
//     error => {
//         return Promise.reject(error)
//     }
// )
//
// // 响应拦截器即异常处理
// axios.interceptors.response.use(
//     response => {
//         return response
//     },
//     error => {
//         Message({
//             message: error.message,
//             type: 'error',
//             duration: 5000
//         })
//         return Promise.resolve(error)
//     }
// )

//网络请求
export default function ajax(url, data = {}, type = 'GET', isupload) {
    url = BASE_URL + url;
    return new Promise(function (resolve) {
        let promise;
        if (type === 'GET') {
            let dataStr = '';
            Object.keys(data).forEach(key => {
                dataStr += key + '=' + data[key] + '&'
            });
            if (dataStr !== '') {
                dataStr = dataStr.substring(0, dataStr.lastIndexOf('&'));
                url = url + '?' + dataStr
            }

            promise = axios.get(url, {
                headers: {
                    'sessionId': storageUtil.read("sessionId")
                }
            })
        } else {
            if (isupload) {
                promise = axios.post(url, data, {
                    headers: {
                        'sessionId': storageUtil.read("sessionId"),
                        'Content-Type': 'multipart/form-data'
                    },
                    transformRequest: [function (data) {
                        return data
                    }]
                })
            } else {
                promise = axios.post(url, qs.stringify(data), {
                    headers: {
                        'sessionId': storageUtil.read("sessionId")
                    }
                })
            }
        }
        promise.then(function (response) {
            if (response.data.code == 0) {
                resolve(response.data)
            } else if (response.data.code == 2) {
                Message({
                    message: '登录失效,请重新登录',
                    type: 'error',
                    duration: 5000
                });
                storageUtil.clear('sessionId');
                router.replace("/login");
            } else {
                if (response.data.message) {
                    Message({
                        message: response.data.message,
                        type: 'error',
                        duration: 5000
                    });
                }
                resolve(response.data)
            }
        }).catch(function (error) {
            Message({
                message: '系统异常，请联系管理员',
                type: 'error',
                duration: 5000
            });
            // console.error("异常", error);
            resolve({code: 500, message: error})
        })
    })
}

//断网处理或者请求超时
// if (!error.response) {
//     //请求超时
//     if (error.message.includes("timeout")) {
//         console.log("超时了");
//         messages("error", "请求超时，请检查互联网连接");
//     } else {
//         //断网，可以展示断网组件
//         console.log("断网了");
//         messages("error", "请检查网络是否已连接");
//     }
//     return;
// }
// const status = error.response.status;
// switch (status) {
//     case 500:
//         messages("error", "服务器内部错误");
//         break;
//     case 404:
//         messages(
//             "error",
//             "未找到远程服务器"
//         );
//         break;
//     case 401:
//         messages("warning", "用户登陆过期，请重新登陆");
//         store.state.commit('COMMIT_TOKEN','')
//         setTimeout(() => {
//             router.replace({
//                 path: "/login",
//                 query: {
//                     redirect: router.currentRoute.fullPath
//                 }
//             });
//         }, 1000);
//         break;
//     case 400:
//         messages("error", "数据异常，详情请咨询服务热线");
//         break;
//     default:
//         messages("error", error.response.data.message);
// }
