import ajax from './ajax'
import axios from 'axios'
import { Message } from "element-ui";
import storageUtil from "../util/storageUtil";
import router from "../router";
import {BASE_URL} from './baseUrl'

//0.联合请求
export const userInfo = () => {
    return new Promise((resolve => {
        axios.all([axios.get(BASE_URL+'/sys/login/session', {
            headers: {
                'sessionId': storageUtil.read("sessionId")
            }
        }), axios.get(BASE_URL+'/sys/menu/loginerRoleMenu', {
            headers: {
                'sessionId': storageUtil.read("sessionId")
            }
        })])
            .then(axios.spread(function (userResult, roleResult) {
                if (userResult.data.code == 0) {
                    resolve({ userResult, roleResult });
                } else if (userResult.data.code == 2) {
                    Message({
                        message: '登录失效,请重新登录',
                        type: 'error',
                        duration: 5000
                    });
                    storageUtil.clear('sessionId');
                    router.replace("/login");
                } else {
                    if (userResult.data.message) {
                        Message({
                            message: userResult.data.message,
                            type: 'error',
                            duration: 5000
                        });
                    }
                    resolve({ userResult, roleResult });
                }
            })).catch(function (error) {
                Message({
                    message: '系统异常，请联系管理员',
                    type: 'error',
                    duration: 5000
                });
                // console.error("异常", error);
                resolve({ code: 500, message: error })
            });
    }));

};

export const getZip = (params) => ajax(`/info/allImageCount`,params, 'GET');

//0.民政平台连接探访系统
export const userConnection = (params) =>
    ajax('/sys/login/connection', params, 'POST');
//1. 用户登录
export const userLogin = (params) =>
    ajax('/sys/login/in', params, 'GET');
//2.退出系统
export const userLogout = () =>
    ajax('/sys/login/out', {}, 'GET');
//3.获取用户信息
// export const userInfo = () =>
//     ajax('/sys/login/session', {}, 'GET');

//4.用户证件上传
export const userUpload = (params) =>
    ajax('/sys/user/upload', params, 'POST', true);
//5.批量添加用户
export const userBatchInsert = (params) =>
    ajax('/sys/user/batchAdd', params, 'POST');
//6.用户修改
export const userUpdate = (params) =>
    ajax('/sys/user/update', params, 'POST');
//7. 修改登录人的个人信息
export const updateInfo = (params) =>
    ajax('/sys/user/updateInfo', params, "POST");
// 8. 修改登录人的密码
export const updatePassword = (params) =>
    ajax('/sys/user/updatePwd', params, "GET");
//9.重置密码
export const setPassword = (params) =>
    ajax('/sys/user/setPassword', params, "GET");
//10 解除绑定
export const setOpenId = (params) =>
    ajax('/sys/user/setOpenId', params, "GET");
//11.用户信息单条查询
export const queryUserOne = (params) =>
    ajax('/sys/user/one', params, "GET");
//12.用户删除
export const userDelete = (params) =>
    ajax('/sys/user/delete', params, "GET");
//13.用户分页查询
export const queryUserForPage = (params) =>
    ajax('/sys/user/listForPage', params, "GET");

//20.采集记录分页
export const queryInfoForPage = (params) =>
    ajax('/info/listForPage', params, "GET");
//21.采集记录删除
export const infoDelete = (params) =>
    ajax('/info/delete', params, "GET");
//21.采集记录审核(2.审核中 3.审核完成 4.失败)
export const infoApproval = (params) =>
    ajax('/info/approval', params, "GET");
//22采集记录筛选重复项
export const groupByNumber = (params) =>
    ajax('/info/groupByNumber', params, "GET");
//23修改老人状态
export const isDeath = (params) =>
    ajax('/info/isDeath', params, "GET");

//30.巡访记录分页
export const queryVisitForPage = (params) =>
    ajax('/visit/listForPage', params, "GET");
//31.巡访记录删除
export const visitDelete = (params) =>
    ajax('/visit/delete', params, "GET");
//32.巡访记录删除
export const careOldPersonForPage = (params) =>
    ajax('/visit/careOldPerson', params, "GET");
//33.巡访记录单查
export const careParticulars = (params) =>
    ajax('/visit/careParticulars', params, "GET");


//40.积分记录分页
export const queryValueForPage = (params) =>
    ajax('/sys/user/values', params, "GET");
//41.积分详情
export const userValueDetails = (params) =>
    ajax('/value/userValueDetails', params, "GET");

//50.操作手册文件上传
export const ManualUp = (id, params) =>
    ajax('/operationManual/upload?id=' + id, params, 'POST', true);
//51.操作手册文件单条查询
export const ManualOne = (params) =>
    ajax('/operationManual/one', params, 'GET');
//52.操作手册文件分页查询
export const ManualListForPage = (params) =>
    ajax('/operationManual/listForPage', params, 'GET');

//60.角色信息修改
export const roleUpdate = (params) =>
    ajax('/sys/role/update', params, 'POST');
//61.角色信息单条查询
export const queryRoleOne = (params) =>
    ajax('/sys/role/one', params, 'GET');
//62.角色分页查询
export const queryRoleForPage = (params) =>
    ajax('/sys/role/listForPage', params, 'GET');

//70.菜单添加
export const menuInsert = (params) =>
    ajax('/sys/menu/add', params, 'POST');
//71.菜单修改
export const menuUpdate = (params) =>
    ajax('/sys/menu/update', params, 'POST');
//72.菜单删除
export const menuDelete = (params) =>
    ajax('/sys/menu/delete', params, 'GET');
//73.菜单单条查询
export const queryMenuOne = (params) =>
    ajax('/sys/menu/one', params, 'GET');
//74.菜单列表
export const queryMenuForList = () =>
    ajax('/sys/menu/list', {}, 'GET');
//75.菜单分页查询
export const queryMenuForPage = (params) =>
    ajax('/sys/menu/listForPage', params, 'GET');
//76.加载登录人的菜单权限
// export const loadLoginerRoleMenus = () =>
//     ajax('/sys/menu/loginerRoleMenu', {}, 'GET');

//80.字典信息添加
export const dictInsert = (params) =>
    ajax('/sys/dict/add', params, 'POST');
//81.字典信息修改
export const dictUpdate = (params) =>
    ajax('/sys/dict/update', params, 'POST');
//82.字典信息删除
export const dictDelete = (params) =>
    ajax('/sys/dict/delete', params, 'GET');
//83.字典单条查询
export const queryDictOne = (params) =>
    ajax('/sys/dict/one', params, 'GET');
//84.字典分页查询
export const queryDictForPage = (params) =>
    ajax('/sys/dict/listForPage', params, 'GET');

//90.部门信息添加
export const deptInsert = (params) =>
    ajax('/sys/dept/add', params, 'POST');
//91.部门信息修改
export const deptUpdate = (params) =>
    ajax('/sys/dept/update', params, 'POST');
//92.部门单条查询
export const queryDeptOne = (params) =>
    ajax('/sys/dept/one', params, 'GET');
//93.部门信息删除
export const deptDelete = (params) =>
    ajax('/sys/dept/delete', params, 'GET');
//94.部门列表
export const queryDeptListByLevel = (params) =>
    ajax('/sys/dept/listByLevel', params, 'GET');
//95.部门分页查询
export const queryDeptForPage = (params) =>
    ajax('/sys/dept/listForPage', params, 'GET');
//96.部门上下移动
export const deptOrderChang = (params) =>
    ajax('/sys/dept/orderChange', params, 'GET');
//96.部门搜索链
export const deptLink = (params) =>
    ajax('/sys/dept/link', params, 'GET');

//部门数据迁移
export const updateData = (params) =>
    ajax('/sys/dept/updateData', params, 'POST');
//部门数据单查
export const listDept = (params) =>
    ajax('/sys/dept/listDept', params, 'GET');

//100.图表数据
export const Chart = (params) =>
    ajax('/chart/statistics', params, 'GET');
//采集员图表数据
export const statisticsUser = (params) =>
    ajax('/chart/statistics/user', params, 'GET');
//采集图表数据
export const statisticsInfo = (params) =>
    ajax('/chart/statistics/info', params, 'GET');
//老人类别图表数据
export const statisticsOldType = (params) =>
    ajax('/chart/statistics/oldType', params, 'GET');
//101.图表数据2
export const chartTwo = (params) =>
    ajax('/chart/dept3Statistics', params, 'GET');

//101.采集筛选报表
export const exportExcelByInfo = (params) =>
    ajax('/info/exportExcelByInfo', params, 'GET');

//101.个人积分排序图表
export const chartFour = (params) =>
    ajax('/chart/userValues', params, 'GET');
//101.地区积分排序图表
export const chartThree = (params) =>
    ajax('/chart/deptValues', params, 'GET');

export const chartFive = (params) =>
    ajax('/chart/visitDeptStatistics', params, 'GET');

export const chartSix = (params) =>
    ajax('/chart/visitDept3Statistics', params, 'GET');

//紧急需求图表
export const chartUrgency = (params) =>
    ajax('/chart/urgency', params, 'GET');

// 日志
export const queryLogForPage = (params) =>
    ajax('/sys/log/listForPage', params, 'GET');
export const queryLogForList = () =>
    ajax('/sys/log/list', {}, 'GET');
export const logDelete = (params) =>
    ajax('/sys/log/delete', params, "GET");
//已绑定子女查询
export const familyForPage = (params) =>
    ajax('/family/bindList', params, "GET");
export const familyForList = (params) =>
    ajax('/family/bindList', params, "GET");

//通知
export const noticeAdd = (params) =>
    ajax('/appletNotice/add', params, 'POST');
export const noticeForPage = (params) =>
    ajax('/appletNotice/listForPage', params, 'GET');
export const noticeDelete = (params) =>
    ajax('/appletNotice/delete', params, "GET");
export const noticeOne = (params) =>
    ajax('/appletNotice/one', params, 'GET');
export const noticeUpdate = (params) =>
    ajax('/appletNotice/update', params, 'POST');

//欢迎语
export const HelloNoticeAdd = (params) =>
    ajax('/welcomeMessage/add', params, 'POST');
export const HelloNoticeForPage = (params) =>
    ajax('/welcomeMessage/listForPage', params, 'GET');
export const HelloNoticeDelete = (params) =>
    ajax('/welcomeMessage/delete', params, "GET");
export const HelloNoticeOne = (params) =>
    ajax('/welcomeMessage/one', params, 'GET');
export const HelloNoticeUpdate = (params) =>
    ajax('/welcomeMessage/update', params, 'POST');

//轮播
export const BannerAdd = (params) =>
    ajax('/banner/add', params, 'POST');
export const BannerForPage = (params) =>
    ajax('/banner/listForPage', params, 'GET');
export const BannerDelete = (params) =>
    ajax('/banner/delete', params, "GET");
export const BannerOne = (params) =>
    ajax('/banner/one', params, 'GET');
export const BannerUpdate = (params) =>
    ajax('/banner/update', params, 'POST');

//紧急通知
export const UrgencyForPage= (params) =>
    ajax('/urgency/listForPage', params, "GET");
export const UrgencyUpdate = (params) =>
    ajax('/urgency/update', params, 'POST');

//意见反馈
export const FeedbackForPage= (params) =>
    ajax('/feedback/listForPage', params, "GET");
export const FeedbackDelete= (params) =>
    ajax('/feedback/delete', params, "GET");

//首页
//昨日采集数据
export const sevendayNum= (params) =>
    ajax('/visit/sevendayNum', params, "GET");
//近七日探访数据
export const yestdayNum= (params) =>
    ajax('/info/yestdayNum', params, "GET");
//审批待处理+紧急通知
export const urgencyFirst= (params) =>
    ajax('/urgency/urgencyFirst', params, "GET");

//老人单查
export const wxinfoOne= (params) =>
    ajax('/wxinfo/one', params, "GET");
//获取oss
export const getALiOssToken= (params) =>
    ajax('/oss/getALiOssToken', params, "GET");
