/* eslint-disable no-console */
import Vue from 'vue'
import App from './App.vue'
import router from './router/index'
import store from './store/index'
import axios from 'axios'
import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import storageUtil from './util/storageUtil'
import data from './util/data'
import config from './util/config'
import Page from './components/Page'
import DynamicTable from './components/DynamicTable'
import DynamicForm from './components/DynamicForm'
import DeptCascader from './components/DeptCascader'
import BreadCrumbs from './components/BreadCrumbs'
import dayjs from 'dayjs'

import md5 from 'js-md5';
import qs from 'qs';
import echarts from 'echarts'
import { BASE_URL } from "./api/baseUrl";

const errorHandler = (error, vm) => {
    console.error('系统异常，请联系管理员');
    console.error("js异常", error, vm);
};

Vue.config.errorHandler = errorHandler;
Vue.prototype.$throw = (error) => errorHandler(error, this);
Vue.use(ElementUI);
Vue.use(Page);
Vue.use(DynamicTable);
Vue.use(DynamicForm);
Vue.use(DeptCascader);
Vue.component('Page', Page);
Vue.component('DynamicTable', DynamicTable);
Vue.component('DynamicForm', DynamicForm);
Vue.component('DeptCascader', DeptCascader);
Vue.component('BreadCrumbs', BreadCrumbs);


// 在正式环境不显示一些警告
Vue.config.productionTip = false;
Vue.prototype.$axios = axios;
Vue.prototype.storageUtil = storageUtil;
Vue.prototype.$dict = data;
Vue.prototype.$baseConfig = config;
Vue.prototype.$md5 = md5;
Vue.prototype.$echarts = echarts;
Vue.prototype.$limitPhotoCount = 10;
Vue.prototype.serverUrl = BASE_URL;
Vue.prototype.$qs = qs;
Vue.prototype.$dayjs = dayjs;


router.beforeEach((to, from, next) => {
    // 判断从大屏跳转，链接中带？的情况做处理。如果其他页面的链接中有以？方式传递参数 此处需要修改
    // if(to.path=="/home"&&to.query.sessionId) {
    //     if (window.location.hash.indexOf("?") != -1) {
    //         let reg = new RegExp("(^|&)" + 'sessionId' + "=([^&]*)(&|$)", "i");
    //         let r = window.location.hash.split("?")[1].match(reg);
    //         if (r) {
    //             let index = r[0].lastIndexOf("=");
    //             let id = r[0].substring(index + 1, r[0].length);
    //             if (id == '0') {
    //                 if (to.fullPath === '/home') {
    //                     next();
    //                 } else {
    //                     next('/home')
    //                 }
    //                 return false;
    //             } else {
    //                 storageUtil.save('sessionId', id);
    //                 if (to.path === '/home') {
    //                     next();
    //                 } else {
    //                     next('/home?id=' + id);
    //                 }
    //             }
    //         }
    //         return false
    //     }
    // }
    const type = to.meta.type;
    if (type == 'connection'){
        storageUtil.clear("sessionId");
    }
    if (type === 'login') {
        if (storageUtil.read('sessionId')) {
            next();
        } else {
            next('/login');
        }
    }else {
        if (storageUtil.read('sessionId')) {
            next('/home');
        }
        next();
    }

    // 访问非权限页面  必须看当前用户是否存在该角色
    // if (to.meta.roles) {
    //     // to.meta.roles.includes(...store.getters.roles) ? next() : next('/403')
    //     isHasRole ? next() : next('/403')
    // } else {
    //     next()
    // }
});

router.afterEach((to) => {
    window.document.title = to.meta.title || '吉林省民政厅居家老年人巡访关爱信息系统'
});


new Vue({
    render: h => h(App),
    router,
    store
}).$mount('#app');
