import Vue from 'vue'
import VueRouter from 'vue-router'

Vue.use(VueRouter);

// 通用获取组件的方法
const getComponent = (component) => () => import(`../pages/${component}/${component}.vue`);
// 通用获取组件的方法
// const getComponent = (name, component) => () => import(`@/views/${name}/${component}.vue`)
// const getComponent = (name, component) => () => import(`@/views/${name}.vue`)

// 定义 path : '/x/:a/y/:b' 动态路由   当前路径是/x/?/y/? 的都导航到它  并且route.params ={a:?,b:?}
// route.query  是路径后面的?c=?  => {c:?}
// 从1个动态路由到动态路由 生命周期不会重走,但是当前的route会变化,可以watch它  或者回调方法beforeRouteUpdate
// route.params.pathMatch 匹配路径中*部分的数值
// push == to  replace == to+replace 可以传递参数{path: name: params:(有path没用) query: }
// TODO 路由组件传参 再看一次  API 和高阶 还是得多看

export default new VueRouter({
    // mode: 'history',
    // base: process.env.BASE_URL,
    // component : 写一个就是默认  components:{default:xxx,a:组件A,b:组件B...} 写多个带名字的router
    routes: [
        {
            path: '/',
            // alias: '/xx',
            component: getComponent('Login'),
            meta: {
                type: ''
            }
        },
        {
            path: '/connection/:token',
            component: getComponent('Connection'),
            meta: {
                type: 'connection'
            }
        },
        {
            path: '/login',
            component: getComponent('Login'),
            meta: {
                type: ''
            }
        },
        {
            path: '/home',
            component: getComponent('Home'),
            meta: {
                type: 'login'
            },
            children: [
                {
                    path: '/',
                    component: getComponent('Index'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/menu',
                    component: getComponent('Menu'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/log',
                    component: getComponent('Log'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/family',
                    component: getComponent('Family'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/role',
                    component: getComponent('Role'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/dict',
                    component: getComponent('Dict'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/file',
                    component: getComponent('File'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/dept',
                    component: getComponent('Dept'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/user',
                    component: getComponent('User'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/collectionUser',
                    component: getComponent('CollectionUser'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/notice',
                    component: getComponent('Notice'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/helloNotice',
                    component: getComponent('HelloNotice'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/opinion',
                    component: getComponent('Opinion'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/opinion',
                    component: getComponent('Banner'),
                    meta: {
                        type: 'login'
                    }
                },

                {
                    path: '/home/info/:id',
                    component: getComponent('Info'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/infoStatistics',
                    component: getComponent('Value'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/Visit',
                    component: getComponent('Visit'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/UrgentNotice',
                    component: getComponent('UrgentNotice'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/Chart',
                    component: getComponent('Chart'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartUser',
                    component: getComponent('ChartUser'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartUserNumber',
                    component: getComponent('ChartUserNumber'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartInfo',
                    component: getComponent('ChartInfo'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartOldType',
                    component: getComponent('ChartOldType'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartTwo',
                    component: getComponent('ChartTwo'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartThree',
                    component: getComponent('ChartThree'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartFour',
                    component: getComponent('ChartFour'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartFive',
                    component: getComponent('ChartFive'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartSix',
                    component: getComponent('ChartSix'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '/home/ChartUrgentNeeds',
                    component: getComponent('ChartUrgentNeeds'),
                    meta: {
                        type: 'login'
                    }
                },
                {
                    path: '404',
                    component: getComponent('404'),
                    meta: {
                        title: '404'
                    }
                },
                {
                    path: '403',
                    component: getComponent('403'),
                    meta: {
                        title: '403'
                    }
                },
                {
                    path: '*',
                    redirect: '404'
                }

            ],

        },
    ],
    // 滚动行为  让每次导航  如果支持pushState就是浏览器的前进后退保存位置 就用，不支持就滚到顶部
    // scrollBehavior (to, from, savedPosition) {
    //     if (savedPosition) {
    //         return savedPosition
    //     } else {
    //         return { x: 0, y: 0 }
    //     }
    // }
});
