import Vue from 'vue'
import Vuex from 'vuex'; // 引入Vuex
import { userInfo } from '../api'
import data from '../util/data'
import storageUtil from '../util/storageUtil'

Vue.use(Vuex); // 启用Vuex

//会加到store里面 调用用  testStore.test
const testStore = {
    state: {
        test: '软件学院',
    }
};
export default new Vuex.Store({
    modules: {
        testStore,
    },
    // 类似 vue 的 data
    state: {
        userInfo: {
          dept:{},
          role:{},
        },
        menu: {},
        routeArr: [],
        isAdd: false,
    },
    // 类似 vue 的 computed -----------------以下5行为新增
    getters: {
        getLoginName: state => {
            return state.userInfo.loginName;
        },
        getLoginDeptName: state => {
            const deptName = data.checkDeptName(state.userInfo, 'dept1')
                + data.checkDeptName(state.userInfo, 'dept2')
                + data.checkDeptName(state.userInfo, 'dept3')
                + data.checkDeptName(state.userInfo, 'dept4')
                + data.checkDeptName(state.userInfo, 'dept5');
            return deptName;
        },
        getLoginDeptNameSimple: state => {
            const deptName = data.checkDeptName(state.userInfo, 'dept1')
                + data.checkDeptName(state.userInfo, 'dept2')
                + data.checkDeptName(state.userInfo, 'dept3')
                + data.checkDeptName(state.userInfo, 'dept4')
                + data.checkDeptName(state.userInfo, 'dept5');
            return deptName.length > 8 ?
                deptName.substring(0, 8) + "..." : deptName;
        },
        getMenuList: state => {
            if (state.menu.data) {
                let ownMenuList = data.ownMenuList(state.menu);
                // console.log(ownMenuList, "目录");
                if (state.userInfo.dept4 || state.userInfo.dept5) {
                    ownMenuList = ownMenuList.filter(value => {
                        return value.address != "/home/ChartTwo" && value.address != "/home/ChartFive" && value.address != "/home/ChartSix"
                    });
                }
                storageUtil.save("addressList", ownMenuList);
                return data.putTree(ownMenuList);
            } else {
                return [];
            }
        }
    },
    // 类似 vue 里的 mothods(同步方法)
    mutations: {
        updateUserInfo(state, data) {
            state.userInfo = data;
        },
        updateUserNameAndPhone(state, data) {
            state.userInfo.userName = data.userName;
            state.userInfo.phone = data.phone;
        },
        updateMenu(state, data) {
            state.menu = data
        },
        pushBreadCrumbs(state, data) {
            state.routeArr.push(data);
        },
        changeBreadCrumbs(state, data) {
            state.routeArr = data;
        },
        changeIsAdd(state, data) {
            state.isAdd = data;
        },
    },

    // 类似 vue 里的 mothods(异步方法) -------- 以下7行为新增  参数是 store
    actions: {
        async getUserInfo({ commit }) {
            const result = await userInfo();
            if (result.status != 500) {
                if(result.userResult.data.data.dept1&&result.userResult.data.data.dept1._id) {
                    storageUtil.save("userDeptId", result.userResult.data.data.dept1._id);
                }
                else
                {
                    storageUtil.save("userDeptId", "");
                }
                commit('updateUserInfo', result.userResult.data.data);
                commit('updateMenu', result.roleResult.data);
                sessionStorage.setItem('sessionStorageUser',JSON.stringify(result.userResult.data.data))
            }
        },
    }
})
